@@ -5,6 +5,8 @@ from nox import Session
 
 from lndb_setup._clone import setup_local_test_postgres
 
+from ._env import get_package_name
+
 
 def login_testuser1(session: Session):
     login_user_1 = "lndb login testuser1@lamin.ai --password cEvcwMJFX4OwbsYVaMt2Os6GxxGgDUlBGILs2RyS"  # noqa
@@ -25,6 +27,25 @@ def setup_test_instances_from_main_branch(session: Session):
         session.run("git", "checkout", os.environ["GITHUB_HEAD_REF"], external=True)
 
 
+def run_pre_commit(session: Session):
+    session.install("pre-commit")
+    session.run("pre-commit", "install")
+    session.run("pre-commit", "run", "--all-files")
+
+
+def install_and_run_pytest(session: Session):
+    package_name = get_package_name()
+    session.install(".[dev,test]")
+    session.run(
+        "pytest",
+        "-s",
+        f"--cov={package_name}",
+        "--cov-append",
+        "--cov-report=term-missing",
+    )
+    session.run("coverage", "xml")
+
+
 def build_docs(session: Session):
     prefix = "." if Path("./lndocs").exists() else ".."
     session.install(f"{prefix}/lndocs")
